#
# This script was written by George A. Theall, <theall@tifaware.com>.
#
# See the Nessus Scripts License for details.
#


if (description) {
  script_id(13647);
  script_version ("$Revision: 1.1 $");
 
  name["english"] = "osTicket setup.php Accessibility";
  script_name(english:name["english"]);
 
  desc["english"] = "
The target host is running an improperly secured installation of
osTicket and allows access to setup.php.  Since that script does not
require authenticated access, it is possible for an attacker to modify
osTicket's configuration using a specially crafted call to setup.php. 

For example, if config.php is writable, an attacker could change the
database used to store ticket information, even redirecting it to
another site.  Alternatively, regardless of whether config.php is
writable, an attacker could cause the loss of all ticket information by
reinitializing the database given knowledge of its existing
configuration (gained, say, from reading config.php). 

Solution : Remove both setup.php and gpcvar.php and ensure permissions
on config.php are 644. 

Risk factor : Low to High";
  script_description(english:desc["english"]);
 
  summary["english"] = "Checks Accessibility of osTicket's setup.php";
  script_summary(english:summary["english"]);
 
  script_category(ACT_GATHER_INFO);
  script_copyright(english:"This script is Copyright (C) 2004 George A. Theall");

  family["english"] = "CGI abuses";
  script_family(english:family["english"]);

  script_dependencie("http_version.nasl");
  script_require_ports("Services/www", 80);

  exit(0);
}

include("global_settings.inc");
include("http_func.inc");
include("http_keepalive.inc");

host = get_host_name();
if (! host) host = string("[", get_host_ip(), "]");
port = get_http_port(default:80);
if (debug_level) display("debug: testing ", host, ":", port, ".\n");

if (!get_port_state(port)) exit(0);
if (!can_host_php(port:port)) exit(0);

# Search for osTicket in a couple of different locations.
#
# NB: Directories beyond cgi_dirs() come from a Google search - 
#     "inurl:open.php osticket" - and represent the more popular
#     installation paths currently. Still, cgi_dirs() should catch
#     the directory if its referenced elsewhere on the target.
dirs = make_list(
  "", 
  "/osticket", 
  "/helpdesk", 
  "/soporte", 
  "/support", 
  "/ticket",
  cgi_dirs()
);
foreach dir (dirs) {
  # Get osTicket's setup.php.
  url = string(dir, "/setup.php");
  if (debug_level) display("debug: checking ", url, ".\n");
  req = http_get(item:url, port:port);
  res = http_keepalive_send_recv(port:port, data:req);
  if (res == NULL) exit(0);           # can't connect
  if (debug_level) display("debug: res =>>", res, "<<\n");

  # If successful and the form is from osTicket, there's a problem.
  if (
    egrep(pattern:"200 OK", string:res, icase:TRUE) &&
    egrep(pattern:'title>osTicket', string:res, icase:TRUE)
  ) {
    security_hole(port:port);
    exit(0);
  }
}
