#
# This script was written by Michael Scheidell SECNAP Network Security
#
# See the Nessus Scripts License for details
# re-release, microsoft patched the patch, new qnumber, registry, etc

if(description)
{
 script_id(11145);
 script_version("$Revision: 1.14 $");
 script_cve_id("CAN-2002-1183","CAN-2002-0862");
 script_bugtraq_id(5410);

 name["english"] = "Certificate Validation Flaw Could Enable Identity Spoofing (Q328145)";
 
 script_name(english:name["english"]);
 
 desc["english"] = "
Hotfix to fix Certificate Validation Flaw (Q329115)
is not installed.

The vulnerability could enable an attacker who had
a valid end-entity certificate to issue a
subordinate certificate that, although bogus,
would nevertheless pass validation. Because
CryptoAPI is used by a wide range of applications,
this could enable a variety of identity spoofing
attacks.
Impact of vulnerability: Identity spoofing. 

Maximum Severity Rating: Critical 

Recommendation: Administrators should install the patch immediately. 

Affected Software: 

Microsoft Windows 98 
Microsoft Windows 98 Second Edition 
Microsoft Windows Me 
Microsoft Windows NT 4.0 
Microsoft Windows NT 4.0, Terminal Server Edition 
Microsoft Windows 2000 
Microsoft Windows XP 
Microsoft Office for Mac 
Microsoft Internet Explorer for Mac 
Microsoft Outlook Express for Mac 

See
http://www.microsoft.com/technet/security/bulletin/ms02-050.mspx

Risk factor : High";

 script_description(english:desc["english"]);
 
 summary["english"] = "Checks for MS Hotfix Q328145, Certificate Validation Flaw";

 script_summary(english:summary["english"]);
 
 script_category(ACT_GATHER_INFO);
 
 script_copyright(english:"This script is Copyright (C) 2002 SECNAP Network Security, LLC");
 family["english"] = "Windows";
 script_family(english:family["english"]);
 
 script_dependencies("netbios_name_get.nasl",
 		     "smb_login.nasl","smb_registry_access.nasl",
		     "smb_reg_service_pack_XP.nasl",
		     "smb_reg_service_pack_W2K.nasl");
 script_require_keys("SMB/name", "SMB/login", "SMB/password",
		     "SMB/WindowsVersion",
		     "SMB/registry_access");

 script_require_ports(139, 445);
 exit(0);
}

include("smb_nt.inc");
port = get_kb_item("SMB/transport");
if(!port)port = 139;


access = get_kb_item("SMB/registry_full_access");
if(!access)exit(0);

version = get_kb_item("SMB/WindowsVersion");

if(ereg(pattern:"([6-9]\.[0-9])|(5\.[2-9])", string:version))exit(0);

key = "SOFTWARE\Microsoft\Windows NT\CurrentVersion\Hotfix\Q329115";
item = "Comments";
value = registry_get_sz(key:key, item:item);
if ( value ) exit(0);

if ("4.0" >< version) 
{
 security_hole(port);
}


if("5.0" >< version)
{
 sp = get_kb_item("SMB/Win2K/ServicePack");
 if(ereg(string:sp, pattern:"Service Pack [4-9]"))exit(0);

 key = "SOFTWARE\Microsoft\Updates\Windows 2000\SP4\Q329115";
 item = "Description";
 value = registry_get_sz(key:key, item:item);
 if(!value)security_hole(port);

}
 


if("5.1" >< version)
{
        key[0] = "SOFTWARE\Microsoft\Updates\Windows XP\SP1\Q329115";
        key[1] = "SOFTWARE\Microsoft\Updates\Windows XP\SP2\Q329115";
        item = "Description";

        for (keyi=0; key[keyi]; keyi++)
        {
            value = registry_get_sz(item:item, key:key[keyi]);
            if ( value ) exit(0);
            value = NULL;
        }

        # Will be fixed in Service Pack 2
        sp = get_kb_item("SMB/WinXP/ServicePack");
        if(ereg(string:sp, pattern:"Service Pack [2-9]"))exit(0);

        security_hole(port);
}




