#
# Noam Rathaus noamr@beyondsecurity.com
#
if(description)
{
 script_id(12267);
 script_bugtraq_id(10487);
 script_cve_id("CAN-2004-0202");
 name["english"] = "Vulnerability in DirectPlay Could Allow Denial of Service (839643)";

 script_name(english:name["english"]);

 desc["english"] = "
A denial of service vulnerability exists in the implementation of the
IDirectPlay4 application programming interface (API) of Microsoft DirectPlay
because of a lack of robust packet validation.

If a user is running a networked DirectPlay application,
an attacker who successfully exploited this vulnerability could
cause the DirectPlay application to fail. The user would have
to restart the application to resume functionality.

Solution : http://www.microsoft.com/technet/security/bulletin/ms04-016.mspx
Risk factor : High";

 script_description(english:desc["english"]);
 
 summary["english"] = "Checks for ms04-016 over the registry";

 script_summary(english:summary["english"]);
 
 script_category(ACT_GATHER_INFO);
 
 script_copyright(english:"This script is Copyright (C) 2004 Noam Rathaus");
 family["english"] = "Windows";
 script_family(english:family["english"]);
 
 script_dependencies("netbios_name_get.nasl",
 		     "smb_login.nasl",
				 "smb_registry_full_access.nasl",
				 "smb_reg_service_pack_W2K.nasl",
		     "smb_reg_service_pack_XP.nasl");
 script_require_keys("SMB/name", "SMB/login", "SMB/password",
		     "SMB/registry_full_access","SMB/WindowsVersion");


 script_require_ports(139, 445);
 exit(0);
}

include("smb_nt.inc");
port = get_kb_item("SMB/transport");
if(!port)port = 139;


access = get_kb_item("SMB/registry_full_access");
if(!access)exit(0);

version = get_kb_item("SMB/WindowsVersion");
if("4.0" >< version )
{
 exit(0);
}

if ( ! version ) exit(0);
key = "SOFTWARE\Microsoft\Windows NT\CurrentVersion\Hotfix\KB839643";
item = "Comments";
value = registry_get_sz(item:item, key:key);
if ( value ) exit(0);

key = "SOFTWARE\Microsoft\Updates\DirectX\DX8\SP1\KB839643-DirectX8";
item = "Description";
value = registry_get_sz(item:item, key:key);
if ( value ) exit(0);

key= "SOFTWARE\Microsoft\Updates\DirectX\DX8.1\SP1\KB839643-DirectX81";
value = registry_get_sz(item:item, key:key);
if ( value ) exit(0);

key = "SOFTWARE\Microsoft\Updates\DirectX\DX8.2\SP1\KB839643-DirectX82";
value = registry_get_sz(item:item, key:key);
if ( value ) exit(0);

key = "SOFTWARE\Microsoft\Updates\DirectX\DX9\SP1\KB839643-DirectX9";
value = registry_get_sz(item:item, key:key);
if ( value ) exit(0);

if("5.0" >< version)
{
 key = "SOFTWARE\Microsoft\Updates\Windows 2000\SP5\KB839643";
 item = "Description";

# Will be fixed in Service Pack 5
 sp = get_kb_item("SMB/Win2K/ServicePack");
 if(ereg(string:sp, pattern:"Service Pack [5-9]"))exit(0);

 value = registry_get_sz(item:item, key:key);
 if(!value)security_hole(port);
}

if("5.1" >< version)
{
# Will be fixed in Service Pack 2
 sp = get_kb_item("SMB/WinXP/ServicePack");
 if(ereg(string:sp, pattern:"Service Pack [2-9]"))exit(0);



 key = "SOFTWARE\Microsoft\Updates\Windows XP\SP1\KB839643";
 item = "Description";
  
 value = registry_get_sz(item:item, key:key);
 if(!value){
 key = "SOFTWARE\Microsoft\Updates\Windows XP\SP2\KB839643";
 value = registry_get_sz(item:item, key:key);
 if ( value ) exit(0);
 }
 else exit(0);
	

 security_hole(port);
}

if("5.2" >< version)
{
 key = "SOFTWARE\Microsoft\Updates\Windows Server 2003\SP1\KB839643";
 item = "Description";
# Will be fixed in Service Pack 1
 sp = get_kb_item("SMB/Win2003/ServicePack");
 if(ereg(string:sp, pattern:"Service Pack [1-9]"))exit(0);
 
 value = registry_get_sz(item:item, key:key);
 if(!value)security_hole(port);
}
